@@ -3,7 +3,7 @@ package Algorithm::Easing;
 use strict;
 use warnings;
 
-our $VERSION = '0.851';
+our $VERSION = '0.852';
 
 1;
 
@@ -124,10 +124,9 @@ Read of a usage example using the proper mediator :
         Return :
             p = position,
             
-        my $p = $obj->ease_both($t,$b,$c,$d);
+        my $p = $obj->ease_none($t,$b,$c,$d);
 
 This method is used for a linear translation between two positive real whole integers using a positive real integer as the parameter for time.
-
 =cut
 
 =head2 ease_in
@@ -141,9 +140,9 @@ This method is used for a linear translation between two positive real whole int
         Return :
             p = position,
             
-        my $p = $obj->ease_both($t,$b,$c,$d);
+        my $p = $obj->ease_in($t,$b,$c,$d);
 
-This method is used for a eased translation between two positive real whole integers as an inward tween using a positive real integer as the parameter for time.
+This method is used to ease in between two positive real whole integers as an inward tween using a positive real integer as the parameter for time in the specified fashion.
 
 =cut
 
@@ -158,9 +157,9 @@ This method is used for a eased translation between two positive real whole inte
         Return :
             p = position,
             
-        my $p = $obj->ease_both($t,$b,$c,$d);
+        my $p = $obj->ease_out($t,$b,$c,$d);
 
-This method is used for a eased translation between two positive real whole integers as an outward tween using a positive real integer as the parameter for time.
+This method is used to ease out between two positive real whole integers as an inward tween using a positive real integer as the parameter for time in the specified fashion.
 
 =cut
 
@@ -177,7 +176,7 @@ This method is used for a eased translation between two positive real whole inte
             
         my $p = $obj->ease_both($t,$b,$c,$d);
 
-This method is used for a eased translation between two positive real whole integers as an inward then outward tween using a positive real integer as the parameter for time.
+This method is used to ease both in then out between two positive real whole integers as an inward tween using a positive real integer as the parameter for time in the specified fashion.
 
 =cut
 
